# My ETH Predictor

This file is for 1 hour predictions

python setup.py sdist bdist_wheel

twine upload dist/* -u __token__ -p pypi-AgEIcHlwaS5vcmcCJGE5MzE1ZGU4LTkyYzMtNDUzNy1hZTFhLWI4YmZjNWJkYjkwYgACKlszLCI5MjZhNDc2Zi05YTVmLTQ3NzItYTE3Mi0wMjAyMWI1YTBmZjEiXQAABiDrM78T4Ko6UGaf5Tg70rQ8tAhZZ7z0hmqOkzTsNeoAgg

## Installation

